Enum smart_fridge::http::error::Error
source · pub enum Error {
Sqlx(Error),
Anyhow(Error),
}Expand description
An API-friendly error type.
Variants
Sqlx(Error)
A SQLx call returned an error.
The exact error contents are not reported to the user in order to avoid leaking information about databse internals.
Anyhow(Error)
Similarly, we don’t want to report random anyhow errors to the user.